@@ -86,4 +86,9 @@ publish("paws-al2", "x86_64");
 publish("runtime-al2", "arm64");
 publish("paws-al2", "arm64");
 
+publish("runtime-al2023", "x86_64");
+publish("paws-al2023", "x86_64");
+publish("runtime-al2023", "arm64");
+publish("paws-al2023", "arm64");
+
 1;
